from . import gtk
from . import torrent
k=gtk.k

slot_bf=k.gtk_entry_buffer_new(b"-1",-1)
con_bf=k.gtk_entry_buffer_new(b"-1",-1)

def store(d):
	d['max_uploads']=getu()
	d['max_connections']=getc()
def restore(d):
	k.gtk_entry_buffer_set_text(slot_bf,str(d['max_uploads']).encode(),-1)
	k.gtk_entry_buffer_set_text(con_bf,str(d['max_connections']).encode(),-1)
	set()

def getu():
	return int(k.gtk_entry_buffer_get_text(slot_bf))
def getc():
	return int(k.gtk_entry_buffer_get_text(con_bf))
def set():
	torrent.ses.set_max_uploads(getu())
	torrent.ses.set_max_connections(getc())




import json

from . import gtk
from . import sets
from . import ratio
from . import next
from . import log
from . import cons
from . import main
k=gtk.k

configs_filename = main.get_root_file('configs')

def write_opt(window):
	dict={}
	width=gtk.c_int()
	height=gtk.c_int()
	k.gtk_window_get_default_size (window, gtk.byref(width), gtk.byref(height))
	dict['max']=k.gtk_window_is_maximized(window)
	dict['width']=width.value
	dict['height']=height.value
	dict['min']=k.gdk_toplevel_get_state(k.gtk_native_get_surface(window))&gtk.GdkToplevelState.GDK_TOPLEVEL_STATE_MINIMIZED
	#
	dict['download_folder']=k.gtk_entry_buffer_get_text(sets.fold_bf).decode()
	ratio.store(dict)
	next.store(dict)
	log.store(dict)
	cons.store(dict)
	with open(configs_filename, "w") as write_file:
		json.dump(dict, write_file)

def read_opt(window):
	global width#used at columns
	try:
		with open(configs_filename) as f:
			dict=json.load(f)
			if dict['max']:
				k.gtk_window_maximize(window)
				disp=k.gdk_display_get_default()
				mon=k.gdk_display_get_monitor_at_surface(disp,k.gtk_native_get_surface(window))
				rct=gtk.GdkRectangle()
				k.gdk_monitor_get_geometry(mon,gtk.byref(rct))
				width=rct.width
			else:
				k.gtk_window_set_default_size(window,width,dict['height'])
				width=dict['width']
			if dict['min']:
				k.gtk_window_minimize(window)
			#
			a=dict['download_folder'].encode()
			k.gtk_entry_buffer_set_text(sets.fold_bf,a,-1)
			ratio.restore(dict)
			next.restore(dict)
			log.restore(dict)
			cons.restore(dict)
	except Exception:
		width=0



"""
torrent client
"""

import appdirs
import os.path
import pathlib
def get_root_dir():
	return pathlib.Path(appdirs.user_config_dir('torra'))
get_root_dir().mkdir(exist_ok=True)
def get_root_file(f):
	return os.path.join(get_root_dir(),f)

from . import gtk
from . import layout
from . import confs
from . import sets
from . import torrent
from . import overall
from . import listtor
from . import ratio
k=gtk.k

@gtk.CALLBACKi
def closing(window):
	listtor.write(layout.list)
	confs.write_opt(window)
	torrent.close()
	overall.close()
	ratio.freeint()
	return False

@gtk.CALLBACK
def activate(app):
	window = k.gtk_application_window_new (app)
	k.gtk_window_set_title (window, b"Torrent")
	k.g_signal_connect_data (window, b"close-request", closing, None, None, 0)
	k.gtk_widget_show (window)
	confs.read_opt(window)
	layout.layout(window)

def main():
	a=k.gtk_application_new(None,0)
	actv=b"activate"
	k.g_signal_connect_data (a, actv, activate, None, None, 0)
	r=k.g_application_run (a,0,None)
	k.g_object_unref(sets.fold_bf)
	k.g_object_unref(a)
	exit(r)

if __name__ == "__main__":
    main()
